import chalk from 'chalk';
import { readdirSync } from 'fs';
import { join } from 'path';

const headPkgList = [];
const pkgList = readdirSync(join(__dirname, 'packages')).filter(
  (pkg) => pkg.charAt(0) !== '.' && !headPkgList.includes(pkg),
);

const alias = pkgList.reduce((pre, pkg) => {
  pre[`@wisdom-components/pro-${pkg}`] = join(__dirname, 'packages', pkg, 'src');
  return {
    ...pre,
  };
}, {});

console.log(`🌼 alias list \n${chalk.blue(Object.keys(alias).join('\n'))}`);

const tailPkgList = pkgList
  .map((path) => [join('packages', path, 'src'), join('packages', path, 'src', 'components')])
  .reduce((acc, val) => acc.concat(val), []);

const isProduction = process.env.NODE_ENV === 'production';

export default {
  title: 'panda-components',
  mode: 'site',
  logo: 'https://panda-water.cn/web4/assets/images/logo/单独图案-蓝绿色.svg',
  extraBabelPlugins: [
    [
      'import',
      {
        libraryName: 'antd',
        libraryDirectory: 'es',
        style: true,
      },
    ],
  ],
  alias,
  resolve: { includes: [...tailPkgList, 'docs'] },
  navs: [
    null,
    {
      title: 'Gitlab',
      path: 'https://g.civnet.cn:8443/test/winsdom-components',
    },
  ],
  hash: true,
  ssr: {
    devServerRender: false,
  },
  targets: {
    chrome: 80,
    firefox: false,
    safari: false,
    edge: false,
    ios: false,
  },
  theme: {
    '@s-site-menu-width': '258px',
  },
  links:
    process.env.NODE_ENV === 'development'
      ? ['https://gw.alipayobjects.com/os/lib/antd/4.6.6/dist/antd.css']
      : [],
  menus: {
    '/components': [
      {
        title: '布局',
        children: ['Empty'],
      },
      {
        title: '通用',
        children: [
          'BasicTable',
          'BasicTools',
          'ImageSelect',
          'QuotaSelect',
          'TimeRangePicker',
          'MqttView',
          'ExportExcel',
        ],
      },
      {
        title: '数据录入',
        children: ['ParseForm'],
      },
      {
        title: '数据展示',
        children: ['DeviceTree', 'RealTimeInfo', 'HistoryInfo'],
      },
    ],
  },
};
