// @ts-ignore
import React, { useEffect, useState } from 'react';
import request from 'umi-request';
import { UnorderedListOutlined, SearchOutlined } from '@ant-design/icons';
import PandaQuotaSelect from '../index';

const Demo = () => {
  const [quotaList, setQuotaList] = useState([]);
  const [selectData, setSelectData] = useState([]);

  const fetchData = () => {
    request(baseUrl + '/Publish/Monitor/Device/GetQuotaList', {
      method: 'get',
      params: {
        accountName: '二供泵房',
        addrSchemeID: '',
      },
    })
      .then(function (response) {
        if (response.code == '0') {
          let curData = response.data.map((item) => ({
            title: item.Name,
            key: item.Name,
            checked: false,
            ...item,
          }));
          setQuotaList(curData);
        }
      })
      .catch(function (error) {
        console.log(error);
      });
  };

  useEffect(() => {
    fetchData();
  }, []);

  const onModalOk = () => {
    console.log('onModalOk');
  };

  const onModalClose = () => {
    console.log('onModalClose');
  };

  const onModalCancel = () => {
    let newQuotaList = [...quotaList];
    newQuotaList.forEach((item) => {
      item.checked = false;
    });
    setQuotaList(newQuotaList);
    setSelectData([]);
    console.log('onModalCancel');
  };

  const onCheckboxChange = (e) => {
    let curData = [...selectData];
    let newQuotaList = [...quotaList];
    let data = curData.filter((item) => item.title === e.target.value);
    if (data.length) {
      curData = curData.filter((item) => item.title !== e.target.value);
    } else {
      curData.push({ key: e.target.value, title: e.target.value });
    }
    newQuotaList.forEach((item) => {
      if (item.title === e.target.value) item.checked = !item.checked;
    });
    setSelectData(curData);
    setQuotaList(newQuotaList);
    console.log(e.target.value, 'onCheckboxChange');
  };

  const onSearch = (e) => {
    if (e.type === 'keydown') {
      console.log(e.target.value, 'onSearch');
    }
  };

  const onRadioChange = (e) => {
    console.log(e, 'onRadioChange');
  };

  const onCancelSelect = ({ title }) => {
    let curData = [...selectData];
    let newQuotaList = [...quotaList];
    let data = curData.filter((item) => item.title !== title);
    newQuotaList.forEach((item) => {
      if (item.title === title) item.checked = !item.checked;
    });
    setSelectData(data);
    setQuotaList(newQuotaList);
    console.log(title, 'onCancelSelect');
  };

  const onDragEnter = (info) => {
    console.log(info, 'onDragEnter');
  };

  const onDrop = (info) => {
    console.log(info, 'onDrop');

    const dropKey = info.node.key;
    const dragKey = info.dragNode.key;
    const dropPos = info.node.pos.split('-');
    const dropPosition = info.dropPosition - Number(dropPos[dropPos.length - 1]);

    const loop = (data, key, callback) => {
      for (let i = 0; i < data.length; i++) {
        if (data[i].key === key) {
          return callback(data[i], i, data);
        }
        if (data[i].children) {
          loop(data[i].children, key, callback);
        }
      }
    };

    const data = [...selectData];

    let dragObj;
    loop(data, dragKey, (item, index, arr) => {
      arr.splice(index, 1);
      dragObj = item;
    });

    if (!info.dropToGap) {
      loop(data, dropKey, (item) => {
        item.children = item.children || [];
        item.children.unshift(dragObj);
      });
    } else if (
      (info.node.props.children || []).length > 0 && // Has children
      info.node.props.expanded && // Is expanded
      dropPosition === 1 // On the bottom gap
    ) {
      loop(data, dropKey, (item) => {
        item.children = item.children || [];
        item.children.unshift(dragObj);
      });
    } else {
      let ar;
      let i;
      loop(data, dropKey, (item, index, arr) => {
        ar = arr;
        i = index;
      });
      if (dropPosition === -1) {
        ar.splice(i, 0, dragObj);
      } else {
        ar.splice(i + 1, 0, dragObj);
      }
    }

    setSelectData(data);
  };

  return (
    <PandaQuotaSelect
      buttonProps={{
        icon: <UnorderedListOutlined />,
        children: `指标选择(${selectData.length})`,
      }}
      onModalCancel={onModalCancel}
      onModalOk={onModalOk}
      onModalClose={onModalClose}
      maximum={3}
      targetValue={'emphasis'}
      dataSource={quotaList}
      selectData={selectData}
      onSearch={onSearch}
      searchPrefix={<SearchOutlined />}
      onRadioChange={onRadioChange}
      onCheckboxChange={onCheckboxChange}
      onCancelSelect={onCancelSelect}
      treeProps={{
        draggable: true,
        onDragEnter,
        onDrop,
      }}
    />
  );
};

export default Demo;

const baseUrl = 'https://www.fastmock.site/mock/162c15dca15c4dba9ba51e0a0b76929b/api';
